@@ -1,7 +1,7 @@
 #ifndef __dconf_mock_h__
 #define __dconf_mock_h__
 
-#include "../gvdb/gvdb-reader.h"
+#include "gvdb/gvdb-reader.h"
 #include <gio/gio.h>
 
 typedef GVariant *   (* DConfMockDBusSyncCallHandler)                   (GBusType             bus_type,
