@@ -25,7 +25,7 @@ dconf_engine_fopen (const char *filename,
   if (filename_to_replace && g_str_equal (filename, filename_to_replace))
     {
       /* Crash if this file was unexpectedly opened */
-      g_assert (filename_to_replace_it_with != NULL);
+      g_assert_nonnull (filename_to_replace_it_with);
       filename = filename_to_replace_it_with;
     }
 
@@ -77,7 +77,7 @@ verify_and_free (DConfEngineSource  **sources,
 
   g_assert_cmpint (n_sources, ==, n_expected);
 
-  g_assert ((sources == NULL) == (n_sources == 0));
+  g_assert_true ((sources == NULL) == (n_sources == 0));
 
   for (i = 0; i < n_sources; i++)
     {
@@ -106,14 +106,14 @@ test_five_times (const gchar *filename,
   va_end (ap);
 
   /* first try by supplying the profile filename via the API */
-  g_assert (g_getenv ("DCONF_PROFILE") == NULL);
-  g_assert (filename_to_replace == NULL);
+  g_assert_null (g_getenv ("DCONF_PROFILE"));
+  g_assert_null (filename_to_replace);
   sources = dconf_engine_profile_open (filename, &n_sources);
   verify_and_free (sources, n_sources, expected_names, n_expected);
 
   /* next try supplying it via the environment */
   g_setenv ("DCONF_PROFILE", filename, TRUE);
-  g_assert (filename_to_replace == NULL);
+  g_assert_null (filename_to_replace);
   sources = dconf_engine_profile_open (NULL, &n_sources);
   verify_and_free (sources, n_sources, expected_names, n_expected);
   g_unsetenv ("DCONF_PROFILE");
@@ -121,7 +121,7 @@ test_five_times (const gchar *filename,
   /* next try supplying a profile name via API and intercepting fopen */
   filename_to_replace = SYSCONFDIR "/dconf/profile/myprofile";
   filename_to_replace_it_with = filename;
-  g_assert (g_getenv ("DCONF_PROFILE") == NULL);
+  g_assert_null (g_getenv ("DCONF_PROFILE"));
   sources = dconf_engine_profile_open ("myprofile", &n_sources);
   verify_and_free (sources, n_sources, expected_names, n_expected);
   filename_to_replace = NULL;
@@ -138,7 +138,7 @@ test_five_times (const gchar *filename,
   /* next try to have dconf pick it up as the default user profile */
   filename_to_replace = SYSCONFDIR "/dconf/profile/user";
   filename_to_replace_it_with = filename;
-  g_assert (g_getenv ("DCONF_PROFILE") == NULL);
+  g_assert_null (g_getenv ("DCONF_PROFILE"));
   sources = dconf_engine_profile_open (NULL, &n_sources);
   verify_and_free (sources, n_sources, expected_names, n_expected);
   filename_to_replace = NULL;
@@ -166,7 +166,7 @@ test_profile_parser_errors (gconstpointer test_data)
 
       sources = dconf_engine_profile_open (data->profile_path, &n_sources);
       g_assert_cmpint (n_sources, ==, 0);
-      g_assert (sources == NULL);
+      g_assert_null (sources);
       return;
     }
 
@@ -199,7 +199,7 @@ test_profile_parser (void)
    */
   filename_to_replace = SYSCONFDIR "/dconf/profile/user";
   filename_to_replace_it_with = SRCDIR "/profile/this-file-does-not-exist";
-  g_assert (g_getenv ("DCONF_PROFILE") == NULL);
+  g_assert_null (g_getenv ("DCONF_PROFILE"));
   sources = dconf_engine_profile_open (NULL, &n_sources);
   filename_to_replace = NULL;
   g_assert_cmpint (n_sources, ==, 1);
@@ -263,21 +263,21 @@ test_user_source (void)
 
   /* Create the source from a clean slate */
   source = dconf_engine_source_new ("user-db:user");
-  g_assert (source != NULL);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_nonnull (source);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
 
   /* Refresh it the first time.
    * This should cause it to open the shm.
    * FALSE should be returned because there is no database file.
    */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
   dconf_mock_shm_assert_log ("open user;");
 
   /* Try to refresh it.  There must be no IO at this point. */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
   dconf_mock_shm_assert_log ("");
 
   /* Add a real database. */
@@ -289,35 +289,35 @@ test_user_source (void)
    * Because we didn't flag the change there must still be no IO.
    */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_false (reopened);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
   dconf_mock_shm_assert_log ("");
 
   /* Now flag it and reopen. */
   dconf_mock_shm_flag ("user");
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values != NULL);
-  g_assert (source->locks == NULL);
-  g_assert (gvdb_table_has_value (source->values, "/values/int32"));
+  g_assert_true (reopened);
+  g_assert_nonnull (source->values);
+  g_assert_null (source->locks);
+  g_assert_true (gvdb_table_has_value (source->values, "/values/int32"));
   dconf_mock_shm_assert_log ("close;open user;");
 
   /* Do it again -- should get the same result, after some IO */
   dconf_mock_shm_flag ("user");
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values != NULL);
-  g_assert (source->locks == NULL);
+  g_assert_true (reopened);
+  g_assert_nonnull (source->values);
+  g_assert_null (source->locks);
   dconf_mock_shm_assert_log ("close;open user;");
 
   /* "Delete" the gvdb and make sure dconf notices after a flag */
   dconf_mock_gvdb_install ("/HOME/.config/dconf/user", NULL);
   dconf_mock_shm_flag ("user");
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_true (reopened);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
   dconf_mock_shm_assert_log ("close;open user;");
 
   /* Add a gvdb with a lock */
@@ -331,19 +331,19 @@ test_user_source (void)
   /* Reopen and check if we have the lock */
   dconf_mock_shm_flag ("user");
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values != NULL);
-  g_assert (source->locks != NULL);
-  g_assert (gvdb_table_has_value (source->values, "/values/int32"));
-  g_assert (gvdb_table_has_value (source->locks, "/values/int32"));
+  g_assert_true (reopened);
+  g_assert_nonnull (source->values);
+  g_assert_nonnull (source->locks);
+  g_assert_true (gvdb_table_has_value (source->values, "/values/int32"));
+  g_assert_true (gvdb_table_has_value (source->locks, "/values/int32"));
   dconf_mock_shm_assert_log ("close;open user;");
 
   /* Reopen one last time */
   dconf_mock_shm_flag ("user");
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values != NULL);
-  g_assert (source->locks != NULL);
+  g_assert_true (reopened);
+  g_assert_nonnull (source->values);
+  g_assert_nonnull (source->locks);
   dconf_mock_shm_assert_log ("close;open user;");
 
   dconf_engine_source_free (source);
@@ -362,36 +362,36 @@ test_file_source (void)
   GVariant *value;
 
   source = dconf_engine_source_new ("file-db:/path/to/db");
-  g_assert (source != NULL);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_nonnull (source);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
   reopened = dconf_engine_source_refresh (source);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
   dconf_engine_source_free (source);
 
   assert_pop_message ("dconf", G_LOG_LEVEL_WARNING, "unable to open file '/path/to/db'");
 
   source = dconf_engine_source_new ("file-db:/path/to/db");
-  g_assert (source != NULL);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_nonnull (source);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
 
   table = dconf_mock_gvdb_table_new ();
   dconf_mock_gvdb_table_insert (table, "/value", g_variant_new_string ("first file"), NULL);
   dconf_mock_gvdb_install ("/path/to/db", table);
 
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values);
-  g_assert (source->locks == NULL);
+  g_assert_true (reopened);
+  g_assert_nonnull (source->values);
+  g_assert_null (source->locks);
   value = gvdb_table_get_value (source->values, "/value");
   g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "first file");
   g_variant_unref (value);
 
   /* Of course this should do nothing... */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
 
   /* Invalidate and replace */
   dconf_mock_gvdb_table_invalidate (table);
@@ -401,7 +401,7 @@ test_file_source (void)
 
   /* Even when invalidated, this should still do nothing... */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
   value = gvdb_table_get_value (source->values, "/value");
   g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "first file");
   g_variant_unref (value);
@@ -436,7 +436,7 @@ handle_service_request (GBusType             bus_type,
       dconf_mock_gvdb_install ("/RUNTIME/dconf-service/shm/nil", service_db_table);
 
       /* Make sure this only happens the first time... */
-      g_assert (!service_db_created);
+      g_assert_false (service_db_created);
       service_db_created = TRUE;
 
       return g_variant_new ("()");
@@ -461,9 +461,9 @@ test_service_source (void)
 
       source = dconf_engine_source_new ("service-db:unknown/nil");
       dconf_mock_dbus_sync_call_handler = handle_service_request;
-      g_assert (source != NULL);
-      g_assert (source->values == NULL);
-      g_assert (source->locks == NULL);
+      g_assert_nonnull (source);
+      g_assert_null (source->values);
+      g_assert_null (source->locks);
       reopened = dconf_engine_source_refresh (source);
 
       return;
@@ -475,9 +475,9 @@ test_service_source (void)
 
   /* Set up one that will work */
   source = dconf_engine_source_new ("service-db:shm/nil");
-  g_assert (source != NULL);
-  g_assert (source->values == NULL);
-  g_assert (source->locks == NULL);
+  g_assert_nonnull (source);
+  g_assert_null (source->values);
+  g_assert_null (source->locks);
 
   /* Refresh it the first time.
    *
@@ -488,12 +488,12 @@ test_service_source (void)
   dconf_mock_dbus_sync_call_handler = handle_service_request;
   reopened = dconf_engine_source_refresh (source);
   dconf_mock_dbus_sync_call_handler = NULL;
-  g_assert (service_db_created);
-  g_assert (reopened);
+  g_assert_true (service_db_created);
+  g_assert_true (reopened);
 
   /* After that, a refresh should be a no-op. */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
 
   /* Close it and reopen it, ensuring that we don't hit the service
    * again (because the file already exists).
@@ -503,12 +503,12 @@ test_service_source (void)
    */
   dconf_engine_source_free (source);
   source = dconf_engine_source_new ("service-db:shm/nil");
-  g_assert (source != NULL);
+  g_assert_nonnull (source);
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
+  g_assert_true (reopened);
 
   /* Make sure it has the content we expect to see */
-  g_assert (gvdb_table_has_value (source->values, "/values/int32"));
+  g_assert_true (gvdb_table_has_value (source->values, "/values/int32"));
 
   /* Now invalidate it and replace it with an empty one */
   dconf_mock_gvdb_table_invalidate (service_db_table);
@@ -517,10 +517,10 @@ test_service_source (void)
 
   /* Now reopening should get the new one */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
+  g_assert_true (reopened);
 
   /* ...and we should find it to be empty */
-  g_assert (!gvdb_table_has_value (source->values, "/values/int32"));
+  g_assert_false (gvdb_table_has_value (source->values, "/values/int32"));
 
   /* We're done. */
   dconf_engine_source_free (source);
@@ -541,7 +541,7 @@ test_system_source (void)
   gboolean reopened;
 
   source = dconf_engine_source_new ("system-db:site");
-  g_assert (source != NULL);
+  g_assert_nonnull (source);
 
   /* Check to see that we get the warning about the missing file. */
   if (g_test_subprocess ())
@@ -550,22 +550,22 @@ test_system_source (void)
 
       /* Failing to open should return FALSE from refresh */
       reopened = dconf_engine_source_refresh (source);
-      g_assert (!reopened);
-      g_assert (source->values == NULL);
+      g_assert_false (reopened);
+      g_assert_null (source->values);
 
       /* Attempt the reopen to make sure we don't get two warnings.
        * We should see FALSE again since we go from NULL to NULL.
        */
       reopened = dconf_engine_source_refresh (source);
-      g_assert (!reopened);
+      g_assert_false (reopened);
 
       /* Create the file after the fact and make sure it opens properly */
       first_table = dconf_mock_gvdb_table_new ();
       dconf_mock_gvdb_install (SYSCONFDIR "/dconf/db/site", first_table);
 
       reopened = dconf_engine_source_refresh (source);
-      g_assert (reopened);
-      g_assert (source->values != NULL);
+      g_assert_true (reopened);
+      g_assert_nonnull (source->values);
 
       dconf_engine_source_free (source);
 
@@ -586,13 +586,13 @@ test_system_source (void)
 
   /* See that we get the database. */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values == first_table);
+  g_assert_true (reopened);
+  g_assert_true (source->values == first_table);
 
   /* Do a refresh, make sure there is no change. */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
-  g_assert (source->values == first_table);
+  g_assert_false (reopened);
+  g_assert_true (source->values == first_table);
 
   /* Replace the table on "disk" but don't invalidate the old one */
   next_table = dconf_mock_gvdb_table_new ();
@@ -600,20 +600,20 @@ test_system_source (void)
 
   /* Make sure the old table remains open (ie: no IO performed) */
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
-  g_assert (source->values == first_table);
+  g_assert_false (reopened);
+  g_assert_true (source->values == first_table);
 
   /* Now mark the first table invalid and reopen */
   dconf_mock_gvdb_table_invalidate (first_table);
   gvdb_table_free (first_table);
   reopened = dconf_engine_source_refresh (source);
-  g_assert (reopened);
-  g_assert (source->values == next_table);
+  g_assert_true (reopened);
+  g_assert_true (source->values == next_table);
 
   /* Remove the file entirely and do the same thing */
   dconf_mock_gvdb_install (SYSCONFDIR "/dconf/db/site", NULL);
   reopened = dconf_engine_source_refresh (source);
-  g_assert (!reopened);
+  g_assert_false (reopened);
 
   dconf_engine_source_free (source);
 }
@@ -795,12 +795,12 @@ check_read (DConfEngine *engine,
 
   if (expected != -1)
     {
-      g_assert (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
+      g_assert_true (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
       g_assert_cmpint (g_variant_get_uint32 (value), ==, expected);
       g_variant_unref (value);
     }
   else
-    g_assert (value == NULL);
+    g_assert_null (value);
 
   /* We are writable if the first database is a user database and we
    * didn't encounter any locks...
@@ -833,12 +833,12 @@ check_read (DConfEngine *engine,
 
       if (our_expected != -1)
         {
-          g_assert (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
+          g_assert_true (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
           g_assert_cmpint (g_variant_get_uint32 (value), ==, our_expected);
           g_variant_unref (value);
         }
       else
-        g_assert (value == NULL);
+        g_assert_null (value);
     }
 
   /* Check listing */
@@ -848,10 +848,10 @@ check_read (DConfEngine *engine,
   if (any_values)
     {
       g_assert_cmpstr (list[0], ==, "value");
-      g_assert (list[1] == NULL);
+      g_assert_null (list[1]);
     }
   else
-    g_assert (list[0] == NULL);
+    g_assert_null (list[0]);
   g_strfreev (list);
 
   /* Check the user value.
@@ -865,8 +865,8 @@ check_read (DConfEngine *engine,
   value = dconf_engine_read (engine, DCONF_READ_USER_VALUE, NULL, "/value");
   if (value)
     {
-      g_assert (first_contents && !(first_contents & 1) && !(source_types & 1));
-      g_assert (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
+      g_assert_true (first_contents && !(first_contents & 1) && !(source_types & 1));
+      g_assert_true (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
       g_assert_cmpint (g_variant_get_uint32 (value), ==, 0);
       g_variant_unref (value);
     }
@@ -877,7 +877,7 @@ check_read (DConfEngine *engine,
        *  - value was missing from first db
        *  - first DB was system-db
        */
-      g_assert (!first_contents || (first_contents & 1) || (source_types & 1));
+      g_assert_true (!first_contents || (first_contents & 1) || (source_types & 1));
     }
 
   /* Check read_through vs. user-value */
@@ -903,17 +903,17 @@ check_read (DConfEngine *engine,
           /* Changeset did nothing, so it should be same as above. */
           if (value)
             {
-              g_assert (first_contents && !(first_contents & 1) && !(source_types & 1));
-              g_assert (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
+              g_assert_true (first_contents && !(first_contents & 1) && !(source_types & 1));
+              g_assert_true (g_variant_is_of_type (value, G_VARIANT_TYPE_UINT32));
               g_assert_cmpint (g_variant_get_uint32 (value), ==, 0);
             }
           else
-            g_assert (!first_contents || (first_contents & 1) || (source_types & 1));
+            g_assert_true (!first_contents || (first_contents & 1) || (source_types & 1));
         }
       else if ((i % 3) == 1)
         {
           /* Changeset did a reset, so we should always see NULL */
-          g_assert (value == NULL);
+          g_assert_null (value);
         }
       else if ((i % 3) == 2)
         {
@@ -1099,7 +1099,7 @@ test_read (void)
               check_read (engine, n, i, k);
               new_state = dconf_engine_get_state (engine);
 
-              g_assert ((j == k) == (new_state == old_state));
+              g_assert_true ((j == k) == (new_state == old_state));
 
               /* Clean up */
               setup_state (n, i, 0, NULL);
@@ -1142,7 +1142,7 @@ test_watch_fast (void)
   a = dconf_engine_get_state (engine);
   dconf_engine_watch_fast (engine, "/a/b/c");
   /* watches do not count as outstanding changes */
-  g_assert (!dconf_engine_has_outstanding (engine));
+  g_assert_false (dconf_engine_has_outstanding (engine));
   dconf_engine_sync (engine);
   b = dconf_engine_get_state (engine);
   g_assert_cmpuint (a, ==, b);
@@ -1162,7 +1162,7 @@ test_watch_fast (void)
   /* Establish a watch and fail the race. */
   a = dconf_engine_get_state (engine);
   dconf_engine_watch_fast (engine, "/a/b/c");
-  g_assert (!dconf_engine_has_outstanding (engine));
+  g_assert_false (dconf_engine_has_outstanding (engine));
   dconf_engine_sync (engine);
   b = dconf_engine_get_state (engine);
   g_assert_cmpuint (a, ==, b);
@@ -1176,7 +1176,7 @@ test_watch_fast (void)
   g_assert_cmpstr (change_log->str, ==, "/a/b/c:1::nil;");
   /* Try to establish a watch again for the same path */
   dconf_engine_watch_fast (engine, "/a/b/c");
-  g_assert (!dconf_engine_has_outstanding (engine));
+  g_assert_false (dconf_engine_has_outstanding (engine));
   dconf_engine_sync (engine);
   c = dconf_engine_get_state (engine);
   g_assert_cmpuint (b, ==, c);
@@ -1403,8 +1403,8 @@ handle_match_request (GBusType             bus_type,
   g_assert_cmpstr (method_name, ==, match_request_type);
   g_assert_cmpstr (g_variant_get_type_string (parameters), ==, "(s)");
   g_variant_get (parameters, "(&s)", &match_rule);
-  g_assert (strstr (match_rule, "arg0path='/a/b/c'"));
-  g_assert (!got_match_request[bus_type]);
+  g_assert_nonnull (strstr (match_rule, "arg0path='/a/b/c'"));
+  g_assert_false (got_match_request[bus_type]);
   got_match_request[bus_type] = TRUE;
 
   return g_variant_new ("()");
@@ -1423,8 +1423,8 @@ test_watch_sync (void)
 
   /* A match rule should be added when the first subscription is established */
   dconf_engine_watch_sync (engine, "/a/b/c");
-  g_assert (got_match_request[G_BUS_TYPE_SESSION]);
-  g_assert (got_match_request[G_BUS_TYPE_SYSTEM]);
+  g_assert_true (got_match_request[G_BUS_TYPE_SESSION]);
+  g_assert_true (got_match_request[G_BUS_TYPE_SYSTEM]);
   got_match_request[G_BUS_TYPE_SESSION] = FALSE;
   got_match_request[G_BUS_TYPE_SYSTEM] = FALSE;
 
@@ -1452,8 +1452,8 @@ test_watch_sync (void)
   /* The match rule should be removed when the last subscription is
    * removed */
   dconf_engine_unwatch_sync (engine, "/a/b/c");
-  g_assert (got_match_request[G_BUS_TYPE_SESSION]);
-  g_assert (got_match_request[G_BUS_TYPE_SYSTEM]);
+  g_assert_true (got_match_request[G_BUS_TYPE_SESSION]);
+  g_assert_true (got_match_request[G_BUS_TYPE_SYSTEM]);
   got_match_request[G_BUS_TYPE_SESSION] = FALSE;
   got_match_request[G_BUS_TYPE_SYSTEM] = FALSE;
 
@@ -1466,7 +1466,7 @@ test_watch_sync (void)
 static void
 test_change_fast (void)
 {
-  DConfChangeset *empty, *good_write, *bad_write, *very_good_write, *slightly_bad_write;
+  DConfChangeset *empty, *good_write, *good_write2, *bad_write, *very_good_write, *slightly_bad_write;
   GvdbTable *table, *locks;
   DConfEngine *engine;
   gboolean success;
@@ -1483,6 +1483,7 @@ test_change_fast (void)
 
   empty = dconf_changeset_new ();
   good_write = dconf_changeset_new_write ("/value", g_variant_new_string ("value"));
+  good_write2 = dconf_changeset_new_write ("/value2", g_variant_new_string ("value2"));
   bad_write = dconf_changeset_new_write ("/locked", g_variant_new_string ("value"));
   very_good_write = dconf_changeset_new_write ("/value", g_variant_new_string ("value"));
   dconf_changeset_set (very_good_write, "/to-reset", NULL);
@@ -1493,21 +1494,21 @@ test_change_fast (void)
 
   success = dconf_engine_change_fast (engine, empty, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   success = dconf_engine_change_fast (engine, empty, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   success = dconf_engine_change_fast (engine, bad_write, NULL, &error);
   g_assert_error (error, DCONF_ERROR, DCONF_ERROR_NOT_WRITABLE);
   g_clear_error (&error);
-  g_assert (!success);
+  g_assert_false (success);
 
   success = dconf_engine_change_fast (engine, slightly_bad_write, NULL, &error);
   g_assert_error (error, DCONF_ERROR, DCONF_ERROR_NOT_WRITABLE);
   g_clear_error (&error);
-  g_assert (!success);
+  g_assert_false (success);
 
   /* Up to now, no D-Bus traffic should have been sent at all because we
    * only had trivial and non-writable attempts.
@@ -1517,9 +1518,18 @@ test_change_fast (void)
   dconf_mock_dbus_assert_no_async ();
   g_assert_cmpstr (change_log->str, ==, "");
 
+  /* Verify that value is unset initially */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
+  g_assert_null (value);
+
+  /* Verify that value2 is unset initially */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value2");
+  g_assert_null (value);
+
+  /* change /value */
   success = dconf_engine_change_fast (engine, good_write, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   /* That should have emitted a synthetic change event */
   g_assert_cmpstr (change_log->str, ==, "/value:1::nil;");
@@ -1530,7 +1540,48 @@ test_change_fast (void)
   g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value");
   g_variant_unref (value);
 
-  /* Fail the attempted write.  This should cause a warning and a change. */
+  /* Repeat the same write for /value (which is already in the in_flight queue) */
+  success = dconf_engine_change_fast (engine, good_write, NULL, &error);
+  g_assert_no_error (error);
+  g_assert_true (success);
+
+  /* Verify that /value is (still) set */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
+  g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value");
+  g_variant_unref (value);
+
+  /* That should not have emitted a synthetic change event, since the (local) value did not change */
+  g_assert_cmpstr (change_log->str, ==, "");
+  g_string_set_size (change_log, 0);
+
+  /* change /value2 */
+  success = dconf_engine_change_fast (engine, good_write2, NULL, &error);
+  g_assert_no_error (error);
+  g_assert_true (success);
+
+  /* That should have emitted a synthetic change event */
+  g_assert_cmpstr (change_log->str, ==, "/value2:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  /* Verify that /value2 is set */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value2");
+  g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value2");
+  g_variant_unref (value);
+
+  /* change /value2 a second time */
+  success = dconf_engine_change_fast (engine, good_write2, NULL, &error);
+  g_assert_no_error (error);
+  g_assert_true (success);
+
+  /* That should not have emitted a synthetic change event because the (local) value didn't change */
+  g_assert_cmpstr (change_log->str, ==, "");
+
+  /* Verify that /value2 is still set */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value2");
+  g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value2");
+  g_variant_unref (value);
+
+  /* Fail the first attempted write.  This should cause a warning and a signal. */
   error = g_error_new_literal (G_FILE_ERROR, G_FILE_ERROR_NOENT, "something failed");
   dconf_mock_dbus_async_reply (NULL, error);
   g_clear_error (&error);
@@ -1539,9 +1590,26 @@ test_change_fast (void)
 
   assert_pop_message ("dconf", G_LOG_LEVEL_WARNING, "failed to commit changes to dconf: something failed");
 
-  /* Verify that the value became unset due to the failure */
-  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "value");
-  g_assert (value == NULL);
+  /* Verify that /value is still set (because the second write is in progress) */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
+  g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value");
+  g_variant_unref (value);
+
+  /* Verify that /value2 is still set because the write is in progress */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value2");
+  g_assert_cmpstr (g_variant_get_string (value, NULL), ==, "value2");
+  g_variant_unref (value);
+
+  /* Now allow the second set of writes to succeed */
+  dconf_mock_dbus_async_reply (g_variant_new ("(s)", "tag"), NULL);
+
+  /* Verify that /value became unset due to the in flight queue clearing */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
+  g_assert_null (value);
+
+  /* Verify that /value2 became unset due to the in flight queue clearing */
+  value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value2");
+  g_assert_null (value);
 
   /* Now try a successful write */
   dconf_mock_dbus_assert_no_async ();
@@ -1549,7 +1617,7 @@ test_change_fast (void)
 
   success = dconf_engine_change_fast (engine, good_write, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   /* That should have emitted a synthetic change event */
   g_assert_cmpstr (change_log->str, ==, "/value:1::nil;");
@@ -1570,14 +1638,14 @@ test_change_fast (void)
   /* Verify that the value became unset due to the in-flight queue
    * clearing... */
   value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "value");
-  g_assert (value == NULL);
+  g_assert_null (value);
 
   /* Do that all again for a changeset with more than one item */
   dconf_mock_dbus_assert_no_async ();
   g_assert_cmpstr (change_log->str, ==, "");
   success = dconf_engine_change_fast (engine, very_good_write, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   g_assert_cmpstr (change_log->str, ==, "/:2:to-reset,value:nil;");
   g_string_set_size (change_log, 0);
   value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
@@ -1590,12 +1658,12 @@ test_change_fast (void)
   g_string_set_size (change_log, 0);
   assert_pop_message ("dconf", G_LOG_LEVEL_WARNING, "failed to commit changes to dconf: something failed");
   value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "value");
-  g_assert (value == NULL);
+  g_assert_null (value);
   dconf_mock_dbus_assert_no_async ();
   g_assert_cmpstr (change_log->str, ==, "");
   success = dconf_engine_change_fast (engine, very_good_write, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   g_assert_cmpstr (change_log->str, ==, "/:2:to-reset,value:nil;");
   g_string_set_size (change_log, 0);
   value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "/value");
@@ -1606,7 +1674,7 @@ test_change_fast (void)
   g_clear_error (&error);
   g_assert_cmpstr (change_log->str, ==, "");
   value = dconf_engine_read (engine, DCONF_READ_FLAGS_NONE, NULL, "value");
-  g_assert (value == NULL);
+  g_assert_null (value);
 
   dconf_engine_unref (engine);
 
@@ -1619,6 +1687,91 @@ test_change_fast (void)
   change_log = NULL;
 }
 
+/**
+ * Tests that dconf_engine_change_fast() emits local optimistic change
+ * notifications in the right circumstances
+ */
+static void
+test_change_fast_redundant (void)
+{
+  DConfChangeset *change;
+  DConfEngine *engine;
+  change_log = g_string_new (NULL);
+
+  // Initialise an empty engine
+  engine = dconf_engine_new (SRCDIR "/profile/dos", NULL, NULL);
+
+  // Send an empty changeset, which has no effect
+  change = dconf_changeset_new ();
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "");
+
+  // Reset the root directory, which has no effect since the database is empty
+  change = dconf_changeset_new_write ("/", NULL);
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "");
+
+  // Set apple to NULL, which has no effect because it was already unset
+  change = dconf_changeset_new_write ("/apple", NULL);
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "");
+
+  // Set apple to apple
+  change = dconf_changeset_new_write ("/apple", g_variant_new_string ("apple"));
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "/apple:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  // Set apple to apple, which has no effect because it is the same as the old value
+  change = dconf_changeset_new_write ("/apple", g_variant_new_string ("apple"));
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "");
+  g_string_set_size (change_log, 0);
+
+  // Set apple to orange, which has an effect because it is different to the old value
+  change = dconf_changeset_new_write ("/apple", g_variant_new_string ("orange"));
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "/apple:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  // Set apple to NULL, which has an effect because it was previously set
+  change = dconf_changeset_new_write ("/apple", NULL);
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "/apple:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  // Set apple to apple
+  change = dconf_changeset_new_write ("/apple", g_variant_new_string ("apple"));
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "/apple:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  // Reset the root directory, which has an effect since the database is not empty
+  change = dconf_changeset_new_write ("/", NULL);
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "/:1::nil;");
+  g_string_set_size (change_log, 0);
+
+  // Reset the root directory again, which has no effect since the database is empty
+  change = dconf_changeset_new_write ("/", NULL);
+  dconf_engine_change_fast (engine, change, NULL, NULL);
+  dconf_changeset_unref (change);
+  g_assert_cmpstr (change_log->str, ==, "");
+
+  dconf_engine_unref (engine);
+  g_string_free (change_log, TRUE);
+  change_log = NULL;
+}
+
 static GError *change_sync_error;
 static GVariant *change_sync_result;
 
@@ -1672,22 +1825,22 @@ test_change_sync (void)
 
   success = dconf_engine_change_sync (engine, empty, &tag, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   g_free (tag);
 
   success = dconf_engine_change_sync (engine, empty, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   success = dconf_engine_change_sync (engine, bad_write, &tag, &error);
   g_assert_error (error, DCONF_ERROR, DCONF_ERROR_NOT_WRITABLE);
   g_clear_error (&error);
-  g_assert (!success);
+  g_assert_false (success);
 
   success = dconf_engine_change_sync (engine, slightly_bad_write, NULL, &error);
   g_assert_error (error, DCONF_ERROR, DCONF_ERROR_NOT_WRITABLE);
   g_clear_error (&error);
-  g_assert (!success);
+  g_assert_false (success);
 
   /* Up to now, no D-Bus traffic should have been sent at all because we
    * only had trivial and non-writable attempts.
@@ -1699,7 +1852,7 @@ test_change_sync (void)
 
   success = dconf_engine_change_sync (engine, good_write, &tag, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   g_assert_cmpstr (tag, ==, "mytag");
   g_free (tag);
   change_sync_result = NULL;
@@ -1707,7 +1860,7 @@ test_change_sync (void)
   change_sync_error = g_error_new_literal (G_FILE_ERROR, G_FILE_ERROR_NOENT, "something failed");
   success = dconf_engine_change_sync (engine, very_good_write, &tag, &error);
   g_assert_error (error, G_FILE_ERROR, G_FILE_ERROR_NOENT);
-  g_assert (!success);
+  g_assert_false (success);
   g_clear_error (&error);
   change_sync_error = NULL;
 
@@ -1836,7 +1989,7 @@ waiter_thread (gpointer user_data)
 
   dconf_engine_sync (engine);
 
-  g_assert (g_atomic_int_get (&it_is_good_to_be_done));
+  g_assert_true (g_atomic_int_get (&it_is_good_to_be_done));
 
   return NULL;
 }
@@ -1866,7 +2019,7 @@ test_sync (void)
   change = dconf_changeset_new_write ("/value", g_variant_new_boolean (TRUE));
   success = dconf_engine_change_fast (engine, change, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
 
   assert_pop_message ("dconf", G_LOG_LEVEL_WARNING, "unable to open file");
 
@@ -1885,7 +2038,7 @@ test_sync (void)
   /* Do the same again, but with a failure as a result */
   success = dconf_engine_change_fast (engine, change, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   for (i = 0; i < G_N_ELEMENTS (waiter_threads); i++)
     waiter_threads[i] = g_thread_new ("test waiter", waiter_thread, engine);
   g_usleep(100 * G_TIME_SPAN_MILLISECOND);
@@ -1906,10 +2059,10 @@ test_sync (void)
    */
   success = dconf_engine_change_fast (engine, change, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   success = dconf_engine_change_fast (engine, change, NULL, &error);
   g_assert_no_error (error);
-  g_assert (success);
+  g_assert_true (success);
   for (i = 0; i < G_N_ELEMENTS (waiter_threads); i++)
     waiter_threads[i] = g_thread_new ("test waiter", waiter_thread, engine);
   g_usleep(100 * G_TIME_SPAN_MILLISECOND);
@@ -2087,6 +2240,7 @@ main (int argc, char **argv)
   g_test_add_func ("/engine/watch/fast/short_lived", test_watch_fast_short_lived_subscriptions);
   g_test_add_func ("/engine/watch/sync", test_watch_sync);
   g_test_add_func ("/engine/change/fast", test_change_fast);
+  g_test_add_func ("/engine/change/fast_redundant", test_change_fast_redundant);
   g_test_add_func ("/engine/change/sync", test_change_sync);
   g_test_add_func ("/engine/signals", test_signals);
   g_test_add_func ("/engine/sync", test_sync);
